@@ -121,7 +121,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         """
 
     def batch_evaluate_feature(
-        self, *, project: str, requests: Sequence["EvaluationRequestTypeDef"]
+        self, *, project: str, requests: Sequence[EvaluationRequestTypeDef]
     ) -> BatchEvaluateFeatureResponseTypeDef:
         """
         This operation assigns feature variation to user sessions.
@@ -141,12 +141,12 @@ class CloudWatchEvidentlyClient(BaseClient):
     def create_experiment(
         self,
         *,
-        metricGoals: Sequence["MetricGoalConfigTypeDef"],
+        metricGoals: Sequence[MetricGoalConfigTypeDef],
         name: str,
         project: str,
-        treatments: Sequence["TreatmentConfigTypeDef"],
+        treatments: Sequence[TreatmentConfigTypeDef],
         description: str = ...,
-        onlineAbConfig: "OnlineAbConfigTypeDef" = ...,
+        onlineAbConfig: OnlineAbConfigTypeDef = ...,
         randomizationSalt: str = ...,
         samplingRate: int = ...,
         tags: Mapping[str, str] = ...
@@ -163,7 +163,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         *,
         name: str,
         project: str,
-        variations: Sequence["VariationConfigTypeDef"],
+        variations: Sequence[VariationConfigTypeDef],
         defaultVariation: str = ...,
         description: str = ...,
         entityOverrides: Mapping[str, str] = ...,
@@ -180,13 +180,13 @@ class CloudWatchEvidentlyClient(BaseClient):
     def create_launch(
         self,
         *,
-        groups: Sequence["LaunchGroupConfigTypeDef"],
+        groups: Sequence[LaunchGroupConfigTypeDef],
         name: str,
         project: str,
         description: str = ...,
-        metricMonitors: Sequence["MetricMonitorConfigTypeDef"] = ...,
+        metricMonitors: Sequence[MetricMonitorConfigTypeDef] = ...,
         randomizationSalt: str = ...,
-        scheduledSplitsConfig: "ScheduledSplitsLaunchConfigTypeDef" = ...,
+        scheduledSplitsConfig: ScheduledSplitsLaunchConfigTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateLaunchResponseTypeDef:
         """
@@ -200,7 +200,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         self,
         *,
         name: str,
-        dataDelivery: "ProjectDataDeliveryConfigTypeDef" = ...,
+        dataDelivery: ProjectDataDeliveryConfigTypeDef = ...,
         description: str = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateProjectResponseTypeDef:
@@ -382,7 +382,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         """
 
     def put_project_events(
-        self, *, events: Sequence["EventTypeDef"], project: str
+        self, *, events: Sequence[EventTypeDef], project: str
     ) -> PutProjectEventsResponseTypeDef:
         """
         Sends performance events to Evidently.
@@ -462,11 +462,11 @@ class CloudWatchEvidentlyClient(BaseClient):
         experiment: str,
         project: str,
         description: str = ...,
-        metricGoals: Sequence["MetricGoalConfigTypeDef"] = ...,
-        onlineAbConfig: "OnlineAbConfigTypeDef" = ...,
+        metricGoals: Sequence[MetricGoalConfigTypeDef] = ...,
+        onlineAbConfig: OnlineAbConfigTypeDef = ...,
         randomizationSalt: str = ...,
         samplingRate: int = ...,
-        treatments: Sequence["TreatmentConfigTypeDef"] = ...
+        treatments: Sequence[TreatmentConfigTypeDef] = ...
     ) -> UpdateExperimentResponseTypeDef:
         """
         Updates an Evidently experiment.
@@ -480,7 +480,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         *,
         feature: str,
         project: str,
-        addOrUpdateVariations: Sequence["VariationConfigTypeDef"] = ...,
+        addOrUpdateVariations: Sequence[VariationConfigTypeDef] = ...,
         defaultVariation: str = ...,
         description: str = ...,
         entityOverrides: Mapping[str, str] = ...,
@@ -500,10 +500,10 @@ class CloudWatchEvidentlyClient(BaseClient):
         launch: str,
         project: str,
         description: str = ...,
-        groups: Sequence["LaunchGroupConfigTypeDef"] = ...,
-        metricMonitors: Sequence["MetricMonitorConfigTypeDef"] = ...,
+        groups: Sequence[LaunchGroupConfigTypeDef] = ...,
+        metricMonitors: Sequence[MetricMonitorConfigTypeDef] = ...,
         randomizationSalt: str = ...,
-        scheduledSplitsConfig: "ScheduledSplitsLaunchConfigTypeDef" = ...
+        scheduledSplitsConfig: ScheduledSplitsLaunchConfigTypeDef = ...
     ) -> UpdateLaunchResponseTypeDef:
         """
         Updates a launch of a given feature.
@@ -526,8 +526,8 @@ class CloudWatchEvidentlyClient(BaseClient):
         self,
         *,
         project: str,
-        cloudWatchLogs: "CloudWatchLogsDestinationConfigTypeDef" = ...,
-        s3Destination: "S3DestinationConfigTypeDef" = ...
+        cloudWatchLogs: CloudWatchLogsDestinationConfigTypeDef = ...,
+        s3Destination: S3DestinationConfigTypeDef = ...
     ) -> UpdateProjectDataDeliveryResponseTypeDef:
         """
         Updates the data storage options for this project.
